@@ -32,6 +32,9 @@ class BadStack(BespinError):
 class BadS3Bucket(BespinError):
     desc = "Bad S3 Bucket"
 
+class BadJson(BespinError):
+    desc = "Bad json"
+
 class FailedStack(BespinError):
     desc = "Something about an stack failed"
 
@@ -41,6 +44,12 @@ class BadYaml(BespinError):
 class BadResult(BespinError):
     desc = "A bad result"
 
+class BadAmazon(BespinError):
+    desc = "Amazon says no"
+
+class StackDoesntExist(BadAmazon):
+    desc = "Missing stack"
+
 class UserQuit(BespinError):
     desc = "User quit the program"
 
